@@ -27,7 +27,7 @@ has baz => (
 );
 
 has bo => (
-    is  => 'wo',
+    is  => 'once',
     isa => HashRef,
 );
 
